==> james-project-3.5.0-source-release.zip: james-project-3.5.0/protocols/imap/src/main/java/org/apache/james/imap/message/request/MoveRequest.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.imap.message.request;

import org.apache.james.imap.api.ImapConstants;
import org.apache.james.imap.api.Tag;
import org.apache.james.imap.api.message.IdRange;
import org.apache.james.imap.api.message.request.ImapRequest;

/**
 * {@link ImapRequest} which request the move of messages
 */
public class MoveRequest extends AbstractMessageRangeRequest {

    public MoveRequest(IdRange[] idSet, String mailboxName, boolean useUids, Tag tag) {
        super(ImapConstants.MOVE_COMMAND, idSet, mailboxName, useUids, tag);
    }

}

==> james-project-3.8.2-source-release.zip: james-project-3.8.2/protocols/imap/src/main/java/org/apache/james/imap/message/request/MoveRequest.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.imap.message.request;

import org.apache.james.imap.api.ImapConstants;
import org.apache.james.imap.api.Tag;
import org.apache.james.imap.api.message.IdRange;
import org.apache.james.imap.api.message.request.ImapRequest;

import com.google.common.base.MoreObjects;

/**
 * {@link ImapRequest} which request the move of messages
 */
public class MoveRequest extends AbstractMessageRangeRequest {

    public MoveRequest(IdRange[] idSet, String mailboxName, boolean useUids, Tag tag) {
        super(ImapConstants.MOVE_COMMAND, idSet, mailboxName, useUids, tag);
    }

    @Override
    public String toString() {
        return MoreObjects.toStringHelper(this)
            .add("idSet", getIdSet())
            .add("mailboxName", getMailboxName())
            .add("useUids", isUseUids())
            .toString();
    }
}
